Home
last modified time | relevance | path

Searched refs:weak (Results 1 – 25 of 308) sorted by relevance

12345678910>>...13

/freebsd-14.2/lib/libc/gen/
H A Ddlfcn.c64 #pragma weak _rtld_error
70 #pragma weak dladdr
79 #pragma weak dlclose
88 #pragma weak dlerror
96 #pragma weak dllockinit
111 #pragma weak dlopen
120 #pragma weak dlsym
129 #pragma weak dlfunc
138 #pragma weak dlvsym
148 #pragma weak dlinfo
[all …]
H A D_spinlock_stub.c49 #pragma weak _spinlock
59 #pragma weak _spinunlock
/freebsd-14.2/contrib/libcxxrt/
H A Dmemory.cc61 __attribute__((weak))
67 __attribute__((weak))
108 __attribute__((weak))
138 __attribute__((weak))
145 __attribute__((weak))
152 __attribute__((weak))
159 __attribute__((weak))
166 __attribute__((weak))
176 __attribute__((weak))
183 __attribute__((weak))
/freebsd-14.2/contrib/llvm-project/clang/lib/Headers/
H A D__clang_hip_runtime_wrapper.h35 __attribute__((weak))
41 __attribute__((weak))
69 __attribute__((noinline, weak)) __device__ void *malloc(__hip_size_t __size) { in malloc()
73 __attribute__((noinline, weak)) __device__ void free(void *__ptr) { in free()
78 __attribute__((weak)) inline __device__ void *malloc(__hip_size_t __size) { in malloc()
81 __attribute__((weak)) inline __device__ void free(void *__ptr) { in free()
89 __attribute__((weak)) inline __device__ void *malloc(__hip_size_t __size) {
92 __attribute__((weak)) inline __device__ void free(void *__ptr) {
96 __attribute__((weak)) inline __device__ void *malloc(__hip_size_t __size) {
100 __attribute__((weak)) inline __device__ void free(void *__ptr) {
/freebsd-14.2/contrib/llvm-project/compiler-rt/lib/scudo/standalone/include/scudo/
H A Dinterface.h17 __attribute__((weak)) const char *__scudo_default_options(void);
20 __attribute__((weak)) void __scudo_allocate_hook(void *ptr, size_t size);
21 __attribute__((weak)) void __scudo_deallocate_hook(void *ptr);
32 __attribute__((weak)) void
34 __attribute__((weak)) void __scudo_realloc_deallocate_hook(void *old_ptr);
/freebsd-14.2/contrib/llvm-project/libunwind/src/
H A DRWMutex.hpp77 extern "C" int __attribute__((weak))
80 extern "C" int __attribute__((weak))
82 extern "C" int __attribute__((weak))
84 extern "C" int __attribute__((weak))
/freebsd-14.2/contrib/llvm-project/compiler-rt/lib/xray/
H A Dxray_init.cpp25 extern const XRaySledEntry __start_xray_instr_map[] __attribute__((weak));
26 extern const XRaySledEntry __stop_xray_instr_map[] __attribute__((weak));
27 extern const XRayFunctionSledIndex __start_xray_fn_idx[] __attribute__((weak));
28 extern const XRayFunctionSledIndex __stop_xray_fn_idx[] __attribute__((weak));
/freebsd-14.2/contrib/file/magic/Magdir/
H A Dweak3 # weak: file(1) magic for very weak magic entries, disabled by default
5 # These entries are so weak that they might interfere identification of
/freebsd-14.2/lib/libc/arm/
H A DSYS.h53 .weak _C_LABEL(x); \
55 .weak _C_LABEL(__CONCAT(_,x)); \
69 .weak _C_LABEL(__CONCAT(_,x)); \
/freebsd-14.2/contrib/llvm-project/openmp/runtime/src/thirdparty/ittnotify/
H A Dittnotify_config.h374 void *dlopen(const char *, int) __attribute__((weak));
375 void *dlsym(void *, const char *) __attribute__((weak));
376 int dlclose(void *) __attribute__((weak));
380 __attribute__((weak));
381 int pthread_mutex_lock(pthread_mutex_t *) __attribute__((weak));
382 int pthread_mutex_unlock(pthread_mutex_t *) __attribute__((weak));
383 int pthread_mutex_destroy(pthread_mutex_t *) __attribute__((weak));
384 int pthread_mutexattr_init(pthread_mutexattr_t *) __attribute__((weak));
385 int pthread_mutexattr_settype(pthread_mutexattr_t *, int) __attribute__((weak));
386 int pthread_mutexattr_destroy(pthread_mutexattr_t *) __attribute__((weak));
[all …]
/freebsd-14.2/sys/contrib/openzfs/module/lua/setjmp/
H A Dsetjmp_ppc.S59 .weak name; \
68 .weak name; \
69 .weak GLUE(.,name); \
86 .weak name; \
/freebsd-14.2/sys/contrib/device-tree/Bindings/power/supply/
H A Dbq2415x.yaml38 ti,weak-battery-voltage:
41 weak battery voltage threshold in mV.
70 - ti,weak-battery-voltage
89 ti,weak-battery-voltage = <3400>;
H A Dbq2415x.txt20 - ti,weak-battery-voltage: integer, weak battery voltage threshold in mV.
40 ti,weak-battery-voltage = <3400>;
/freebsd-14.2/contrib/llvm-project/compiler-rt/lib/builtins/
H A Dcrtbegin.c17 extern void __register_frame_info(const void *, void *) __attribute__((weak));
18 extern void *__deregister_frame_info(const void *) __attribute__((weak));
29 extern void __cxa_finalize(void *) __attribute__((weak));
H A Dint_util.c36 __attribute__((weak))
49 __attribute__((weak))
/freebsd-14.2/contrib/llvm-project/compiler-rt/lib/builtins/arm/
H A Daeabi_div0.c31 AEABI_RTABI int __attribute__((weak)) __attribute__((visibility("hidden")))
36 AEABI_RTABI long long __attribute__((weak))
/freebsd-14.2/sys/libkern/
H A Dexplicit_bzero.c14 __attribute__((weak)) void __explicit_bzero_hook(void *, size_t);
16 __attribute__((weak)) void
/freebsd-14.2/sys/dev/uart/
H A Duart.h112 extern struct uart_class uart_ns8250_class __attribute__((weak));
113 extern struct uart_class uart_quicc_class __attribute__((weak));
114 extern struct uart_class uart_z8530_class __attribute__((weak));
/freebsd-14.2/lib/libc/riscv/sys/
H A D__vdso_gettc.c37 #pragma weak __vdso_gettc
48 #pragma weak __vdso_gettimekeep
/freebsd-14.2/lib/libc/powerpc/sys/
H A D__vdso_gettc.c43 #pragma weak __vdso_gettc
59 #pragma weak __vdso_gettimekeep
/freebsd-14.2/lib/libc/powerpc64/sys/
H A D__vdso_gettc.c42 #pragma weak __vdso_gettc
56 #pragma weak __vdso_gettimekeep
/freebsd-14.2/contrib/llvm-project/compiler-rt/lib/fuzzer/
H A DFuzzerExtraCounters.cpp16 __attribute__((weak)) extern uint8_t __start___libfuzzer_extra_counters;
17 __attribute__((weak)) extern uint8_t __stop___libfuzzer_extra_counters;
/freebsd-14.2/lib/libc/aarch64/sys/
H A D__vdso_gettc.c55 #pragma weak __vdso_gettc
67 #pragma weak __vdso_gettimekeep
/freebsd-14.2/lib/libc/arm/sys/
H A D__vdso_gettc.c60 #pragma weak __vdso_gettc
82 #pragma weak __vdso_gettimekeep
/freebsd-14.2/lib/clang/include/llvm/Config/
H A Dabi-breaking.h48 __attribute__((weak)) int *VerifyEnableABIBreakingChecks =
53 __attribute__((weak)) int *VerifyDisableABIBreakingChecks =

12345678910>>...13